==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_Story.pm <==
package WebGUI::i18n::German::Asset_Story;
use utf8;
our $I18N = {
  'Replace image with new image' => {
    'lastUpdated' => '1251768110',
    'message' => 'Grafik durch neue ersetzen'
  },
  'Source' => {
    'lastUpdated' => '1250933784',
    'message' => 'Quelle'
  },
  'ago' => {
    'lastUpdated' => '1250933814',
    'message' => ' '
  },
  'assetName' => {
    'lastUpdated' => '1250933768',
    'message' => 'Bericht'
  },
  'byline' => {
    'lastUpdated' => '1250974348',
    'message' => 'Autorenzeile'
  },
  'byline help' => {
    'lastUpdated' => '1250974333',
    'message' => 'Wer schrieb den Bericht?'
  },
  'byline tmplvar' => {
    'lastUpdated' => '1250974302',
    'message' => 'Die Autorenzeile des Berichts'
  },
  'bylineForm' => {
    'lastUpdated' => '1250974396',
    'message' => 'Benutzerformular zur Eingabe einer Autorenzeile für diesen Bericht.'
  },
  'canEdit' => {
    'lastUpdated' => '1251768157',
    'message' => 'Ein boolscher Wert, der wahr ist, wenn der aktuelle Benutzer diesen Bericht bearbeiten darf'
  },
  'cancelButton' => {
    'lastUpdated' => '1251768195',
    'message' => 'Button für den Benutzer, um dieses Formular ohne Speichern abzubrechen'
  },
  'crumb_loop' => {
    'lastUpdated' => '1252333306',
    'message' => 'Eine Schleife, die den Crumbtrail enthält. Das erste Element ist der Link zum Archiv, das den Bericht enthält. Das letzte Element ist der Bericht mit Titel und URL. Bei drei Elementen enthält das mittlere das Thema.'
  },
  'crumb_title' => {
    'lastUpdated' => '1252333327',
    'message' => 'Der Seitentitel im Crumbtrail'
  },
  'crumb_url' => {
    'lastUpdated' => '1252333338',
    'message' => 'URL der Seite im Crumbrail'
  },
  'edit template' => {
    'lastUpdated' => '1252333352',
    'message' => 'Berichtstemplate bearbeiten'
  },
  'formFooter' => {
    'lastUpdated' => '1252333404',
    'message' => 'HTML-Endcode des Formulars zum Hinzufügen oder Bearbeiten des Berichts.'
  },
  'formHeader' => {
    'lastUpdated' => '1252333413',
    'message' => 'HTML-Startcode des Formulars zum Hinzufügen oder Bearbeiten des Berichts.'
  },
  'formTitle' => {
    'lastUpdated' => '1252333434',
    'message' => 'Internationalisierter Titel für dieses Formular'
  },
  'hasPhoto' => {
    'lastUpdated' => '1252333519',
    'message' => 'Diese Templatevariable ist wahr wenn photo im photo_loop ein Bild enthält'
  },
  'hasPhotos' => {
    'lastUpdated' => '1252333552',
    'message' => 'Diese Templatevariable ist wahr, wenn zum Bericht Photos hochgeladen wurden'
  },
  'headline' => {
    'lastUpdated' => '1251768363',
    'message' => 'Überschrift'
  },
  'headline help' => {
    'lastUpdated' => '1252333589',
    'message' => 'Meist das selbe wie der Titel. Wenn leer wird als Überschrift der Titel genommen.'
  },
  'headline tmplvar' => {
    'lastUpdated' => '1252333616',
    'message' => 'Überschrift des Berichts'
  },
  'headlineForm' => {
    'lastUpdated' => '1252333647',
    'message' => 'Formular in das der Benutzer die Berichtsüberschrift eingibt'
  },
  'highlight' => {
    'lastUpdated' => '1252333675',
    'message' => 'Ein Highlight ohne Formatierung oder zusätzlichen HTML-Code'
  },
  'highlights' => {
    'lastUpdated' => '1252333684',
    'message' => 'Berichtshighlights'
  },
  'highlights help' => {
    'lastUpdated' => '1252333724',
    'message' => 'Strichaufzählung aus dem Bericht. Zeilenweise'
  },
  'highlights tmplvar' => {
    'lastUpdated' => '1252333762',
    'message' => 'Alle Highlights des Berichts. Die Highlights werden durch Zeilenumbruch getrennt.'
  },
  'highlightsForm' => {
    'lastUpdated' => '1252333787',
    'message' => 'Formular mit dem der Nutzer die Highlights des Berichts eingibt'
  },
  'highlights_loop' => {
    'lastUpdated' => '1252333808',
    'message' => 'Eine Schleife die alle Highlights des Berichts enthält'
  },
  'imageAlt' => {
    'lastUpdated' => '1252333851',
    'message' => 'Alternativtext für das Bild, gebräuchlich für den ALT-Parameter im IMG-Tag'
  },
  'imageByline' => {
    'lastUpdated' => '1252334067',
    'message' => 'Bildunterschrift'
  },
  'imageCaption' => {
    'lastUpdated' => '1252333886',
    'message' => 'Bildüberschrift'
  },
  'imageLink' => {
    'lastUpdated' => '1252333903',
    'message' => 'URL auf den das Bild verweist'
  },
  'imageTitle' => {
    'lastUpdated' => '1252333939',
    'message' => 'Alternativtext für das Bild, gebräuchlich für den TITLE-Parameter im IMG-Tag'
  },
  'imageUrl' => {
    'lastUpdated' => '1252333946',
    'message' => 'URL zum Bild'
  },
  'imgAltForm' => {
    'lastUpdated' => '1252334013',
    'message' => 'Eingabefeld für Alternativtext zum Bild für den ALT-Parameter des IMG-Tags.'
  },
  'imgBylineForm' => {
    'lastUpdated' => '1252334057',
    'message' => 'Formularfeld für die Bildunterschrift'
  },
  'imgCaptionForm' => {
    'lastUpdated' => '1252334080',
    'message' => 'Formularfeld für die Bildüberschrift'
  },
  'imgDeleteForm' => {
    'lastUpdated' => '1252334163',
    'message' => 'Ein Feld, um das Bild mit den dazugehörigen Angaben zu löschen. Das Formular ist nicht in den Variablen der Schleife für Bild-hinzufügen enthalten'
  },
  'imgFilename' => {
    'lastUpdated' => '1252334187',
    'message' => 'URL zum Bild, wenn das Photo ein Bild hat.'
  },
  'imgThumb' => {
    'lastUpdated' => '1252334217',
    'message' => 'URL zum Vorschaubild, wenn das Foto ein Bild hat.'
  },
  'imgTitleForm' => {
    'lastUpdated' => '1252334034',
    'message' => 'Eingabefeld für Titel zum Bild für den TITLE-Parameter des IMG-Tags.'
  },
  'imgUrl' => {
    'lastUpdated' => '1252334235',
    'message' => 'URL zum Bild, wenn das Photo ein Bild hat.'
  },
  'imgUrlForm' => {
    'lastUpdated' => '1252334291',
    'message' => 'Ein Feld für den URL zum Bild. Wenn vorhanden, wird das Bild mit Link zu diesem URL verknüpft.'
  },
  'keyword' => {
    'lastUpdated' => '1251768340',
    'message' => 'Ein Schlüsselwort, ohne Formataierung'
  },
  'keyword_url' => {
    'lastUpdated' => '1252334317',
    'message' => 'URL am alle Berichte im Archiv zu diesem Schlüsselwort anzuzeigen.'
  },
  'keywordsForm' => {
    'lastUpdated' => '1252334370',
    'message' => 'Formular zur Eingabe der Schlüsselworte zu diesem Bericht'
  },
  'keywords_loop' => {
    'lastUpdated' => '1252334400',
    'message' => 'Schleife die alle Schlüsselworte zu diesem Bericht enthält.'
  },
  'location' => {
    'lastUpdated' => '1252334405',
    'message' => 'Ort'
  },
  'location help' => {
    'lastUpdated' => '1252334434',
    'message' => 'Ort an dem der Bericht handelt'
  },
  'location tmplvar' => {
    'lastUpdated' => '1252334443',
    'message' => 'Ort des Berichts'
  },
  'locationForm' => {
    'lastUpdated' => '1252334463',
    'message' => 'Formular zur Eingabe des Ortes zu diesem Bericht'
  },
  'newUploadForm' => {
    'lastUpdated' => '1252334480',
    'message' => 'Formularfeld für Bildupload'
  },
  'photo alt' => {
    'lastUpdated' => '1252334494',
    'message' => 'Alternativtext Photo'
  },
  'photo byline' => {
    'lastUpdated' => '1252334509',
    'message' => 'Photounterschrift'
  },
  'photo caption' => {
    'lastUpdated' => '1252334527',
    'message' => 'Photoüberschrift'
  },
  'photo delete' => {
    'lastUpdated' => '1252334539',
    'message' => 'Photo und Metadaten löschen'
  },
  'photo title' => {
    'lastUpdated' => '1252334549',
    'message' => 'Alternativtitel Photo'
  },
  'photo tmplvar' => {
    'lastUpdated' => '1252334580',
    'message' => 'Photo JSON-Blob vom Berichtsasset'
  },
  'photo url' => {
    'lastUpdated' => '1252334589',
    'message' => 'Photo-URL'
  },
  'photoWidth' => {
    'lastUpdated' => '1253865063',
    'message' => 'Breite der Photos, im Berichtarchiv für diesen Bericht definiert.'
  },
  'photo_form_loop' => {
    'lastUpdated' => '1252334659',
    'message' => 'Eine Schleife, die Unterformulare für alle Photos enthält die geladen wurden und ein Leerformular zum Upload neuer Photos'
  },
  'photo_loop' => {
    'lastUpdated' => '1252334683',
    'message' => 'Eine Schleife die Photos und Informationen zu den Photos enthält.'
  },
  'save and add another photo' => {
    'lastUpdated' => '1252334695',
    'message' => 'Speichern und neues Photo hinzufügen'
  },
  'save story' => {
    'lastUpdated' => '1252334704',
    'message' => 'Bericht speichern'
  },
  'saveAndAddButton' => {
    'lastUpdated' => '1252334769',
    'message' => 'Button zum Speichern des Formulars, dann öffnen des Bearbeitenformulars um ein weiteres Photo anzufügen.'
  },
  'saveButton' => {
    'lastUpdated' => '1252334782',
    'message' => 'Button zum Formularspeichern'
  },
  'singlePhoto' => {
    'lastUpdated' => '1252334992',
    'message' => 'Diese Templatevariable ist wahr, wenn zum Bericht nur 1 Photo hochgeladen wurde.'
  },
  'story' => {
    'lastUpdated' => '1251768283',
    'message' => 'Bericht'
  },
  'story asset template variables title' => {
    'lastUpdated' => '1266397817',
    'message' => '"Bericht"-Asset Template Variabelen'
  },
  'story help' => {
    'lastUpdated' => '1252335008',
    'message' => 'Der Bericht'
  },
  'story received' => {
    'lastUpdated' => '1252335105',
    'message' => 'Der Bericht wurde erhalten und wird nun verarbeitet, so dass er zur Site hinzugefügt werden kann. Nach der Verarbeitung steht wer zur weiteren Bearbeitung zur Verfügung. Bitte haben Sie kurz Geduld.'
  },
  'story tmplvar' => {
    'lastUpdated' => '1252335146',
    'message' => 'Der Bericht. Kann eingebundene Inhalte aus dem Rich Text Editor enthalten.'
  },
  'storyForm' => {
    'lastUpdated' => '1252335169',
    'message' => 'Formular zur Eingabe des aktuellen Berichtes'
  },
  'subtitle' => {
    'lastUpdated' => '1251768302',
    'message' => 'Untertitel'
  },
  'subtitle help' => {
    'lastUpdated' => '1252335203',
    'message' => 'Ähnlich Überschrift, enthält aber meist nähere Informationen'
  },
  'subtitle tmplvar' => {
    'lastUpdated' => '1252335212',
    'message' => 'Untertitel des Berichts'
  },
  'subtitleForm' => {
    'lastUpdated' => '1252335231',
    'message' => 'Formular zur Eingabe des Untertitels zum Bericht'
  },
  'summaryForm' => {
    'lastUpdated' => '1252335250',
    'message' => 'Formular zur Eingabe einer Zusammenfassung zum Bericht'
  },
  'titleForm' => {
    'lastUpdated' => '1251768265',
    'message' => 'Formular zur Eingabe des Berichttitels'
  },
  'updatedTime' => {
    'lastUpdated' => '1266397981',
    'message' => 'Zeitpunkt der letzten Aktualisierung des Berichts. Angabe als Zeitdauer, wie "vor 1 Stunde".'
  },
  'updatedTimeEpoch' => {
    'lastUpdated' => '1266397960',
    'message' => 'Zeitpunkt der letzten Aktualisierung des Berichts als Epoch-Angabe.'
  },
  'view template' => {
    'lastUpdated' => '1251768236',
    'message' => 'Template Bericht anzeigen'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_Story.pm <==
package WebGUI::i18n::German::Asset_Story;
use utf8;
our $I18N = {
  'Replace image with new image' => {
    'lastUpdated' => '1251768110',
    'message' => 'Grafik durch neue ersetzen'
  },
  'Source' => {
    'lastUpdated' => '1250933784',
    'message' => 'Quelle'
  },
  'ago' => {
    'lastUpdated' => '1250933814',
    'message' => ' '
  },
  'assetName' => {
    'lastUpdated' => '1250933768',
    'message' => 'Bericht'
  },
  'byline' => {
    'lastUpdated' => '1250974348',
    'message' => 'Autorenzeile'
  },
  'byline help' => {
    'lastUpdated' => '1250974333',
    'message' => 'Wer schrieb den Bericht?'
  },
  'byline tmplvar' => {
    'lastUpdated' => '1250974302',
    'message' => 'Die Autorenzeile des Berichts'
  },
  'bylineForm' => {
    'lastUpdated' => '1250974396',
    'message' => 'Benutzerformular zur Eingabe einer Autorenzeile für diesen Bericht.'
  },
  'canEdit' => {
    'lastUpdated' => '1251768157',
    'message' => 'Ein boolscher Wert, der wahr ist, wenn der aktuelle Benutzer diesen Bericht bearbeiten darf'
  },
  'cancelButton' => {
    'lastUpdated' => '1251768195',
    'message' => 'Button für den Benutzer, um dieses Formular ohne Speichern abzubrechen'
  },
  'crumb_loop' => {
    'lastUpdated' => '1252333306',
    'message' => 'Eine Schleife, die den Crumbtrail enthält. Das erste Element ist der Link zum Archiv, das den Bericht enthält. Das letzte Element ist der Bericht mit Titel und URL. Bei drei Elementen enthält das mittlere das Thema.'
  },
  'crumb_title' => {
    'lastUpdated' => '1252333327',
    'message' => 'Der Seitentitel im Crumbtrail'
  },
  'crumb_url' => {
    'lastUpdated' => '1252333338',
    'message' => 'URL der Seite im Crumbrail'
  },
  'edit template' => {
    'lastUpdated' => '1252333352',
    'message' => 'Berichtstemplate bearbeiten'
  },
  'formFooter' => {
    'lastUpdated' => '1252333404',
    'message' => 'HTML-Endcode des Formulars zum Hinzufügen oder Bearbeiten des Berichts.'
  },
  'formHeader' => {
    'lastUpdated' => '1252333413',
    'message' => 'HTML-Startcode des Formulars zum Hinzufügen oder Bearbeiten des Berichts.'
  },
  'formTitle' => {
    'lastUpdated' => '1252333434',
    'message' => 'Internationalisierter Titel für dieses Formular'
  },
  'hasPhoto' => {
    'lastUpdated' => '1252333519',
    'message' => 'Diese Templatevariable ist wahr wenn photo im photo_loop ein Bild enthält'
  },
  'hasPhotos' => {
    'lastUpdated' => '1252333552',
    'message' => 'Diese Templatevariable ist wahr, wenn zum Bericht Photos hochgeladen wurden'
  },
  'headline' => {
    'lastUpdated' => '1251768363',
    'message' => 'Überschrift'
  },
  'headline help' => {
    'lastUpdated' => '1252333589',
    'message' => 'Meist das selbe wie der Titel. Wenn leer wird als Überschrift der Titel genommen.'
  },
  'headline tmplvar' => {
    'lastUpdated' => '1252333616',
    'message' => 'Überschrift des Berichts'
  },
  'headlineForm' => {
    'lastUpdated' => '1252333647',
    'message' => 'Formular in das der Benutzer die Berichtsüberschrift eingibt'
  },
  'highlight' => {
    'lastUpdated' => '1252333675',
    'message' => 'Ein Highlight ohne Formatierung oder zusätzlichen HTML-Code'
  },
  'highlights' => {
    'lastUpdated' => '1252333684',
    'message' => 'Berichtshighlights'
  },
  'highlights help' => {
    'lastUpdated' => '1252333724',
    'message' => 'Strichaufzählung aus dem Bericht. Zeilenweise'
  },
  'highlights tmplvar' => {
    'lastUpdated' => '1252333762',
    'message' => 'Alle Highlights des Berichts. Die Highlights werden durch Zeilenumbruch getrennt.'
  },
  'highlightsForm' => {
    'lastUpdated' => '1252333787',
    'message' => 'Formular mit dem der Nutzer die Highlights des Berichts eingibt'
  },
  'highlights_loop' => {
    'lastUpdated' => '1252333808',
    'message' => 'Eine Schleife die alle Highlights des Berichts enthält'
  },
  'imageAlt' => {
    'lastUpdated' => '1252333851',
    'message' => 'Alternativtext für das Bild, gebräuchlich für den ALT-Parameter im IMG-Tag'
  },
  'imageByline' => {
    'lastUpdated' => '1252334067',
    'message' => 'Bildunterschrift'
  },
  'imageCaption' => {
    'lastUpdated' => '1252333886',
    'message' => 'Bildüberschrift'
  },
  'imageLink' => {
    'lastUpdated' => '1252333903',
    'message' => 'URL auf den das Bild verweist'
  },
  'imageTitle' => {
    'lastUpdated' => '1252333939',
    'message' => 'Alternativtext für das Bild, gebräuchlich für den TITLE-Parameter im IMG-Tag'
  },
  'imageUrl' => {
    'lastUpdated' => '1252333946',
    'message' => 'URL zum Bild'
  },
  'imgAltForm' => {
    'lastUpdated' => '1252334013',
    'message' => 'Eingabefeld für Alternativtext zum Bild für den ALT-Parameter des IMG-Tags.'
  },
  'imgBylineForm' => {
    'lastUpdated' => '1252334057',
    'message' => 'Formularfeld für die Bildunterschrift'
  },
  'imgCaptionForm' => {
    'lastUpdated' => '1252334080',
    'message' => 'Formularfeld für die Bildüberschrift'
  },
  'imgDeleteForm' => {
    'lastUpdated' => '1252334163',
    'message' => 'Ein Feld, um das Bild mit den dazugehörigen Angaben zu löschen. Das Formular ist nicht in den Variablen der Schleife für Bild-hinzufügen enthalten'
  },
  'imgFilename' => {
    'lastUpdated' => '1252334187',
    'message' => 'URL zum Bild, wenn das Photo ein Bild hat.'
  },
  'imgRemoteUrlForm' => {
    'lastUpdated' => '1303289510',
    'message' => 'Ein Formular für die Angabe der Remote-URL eines Fotos'
  },
  'imgThumb' => {
    'lastUpdated' => '1252334217',
    'message' => 'URL zum Vorschaubild, wenn das Foto ein Bild hat.'
  },
  'imgTitleForm' => {
    'lastUpdated' => '1252334034',
    'message' => 'Eingabefeld für Titel zum Bild für den TITLE-Parameter des IMG-Tags.'
  },
  'imgUrl' => {
    'lastUpdated' => '1252334235',
    'message' => 'URL zum Bild, wenn das Photo ein Bild hat.'
  },
  'imgUrlForm' => {
    'lastUpdated' => '1252334291',
    'message' => 'Ein Feld für den URL zum Bild. Wenn vorhanden, wird das Bild mit Link zu diesem URL verknüpft.'
  },
  'keyword' => {
    'lastUpdated' => '1251768340',
    'message' => 'Ein Schlüsselwort, ohne Formataierung'
  },
  'keyword_url' => {
    'lastUpdated' => '1252334317',
    'message' => 'URL am alle Berichte im Archiv zu diesem Schlüsselwort anzuzeigen.'
  },
  'keywordsForm' => {
    'lastUpdated' => '1252334370',
    'message' => 'Formular zur Eingabe der Schlüsselworte zu diesem Bericht'
  },
  'keywords_loop' => {
    'lastUpdated' => '1252334400',
    'message' => 'Schleife die alle Schlüsselworte zu diesem Bericht enthält.'
  },
  'location' => {
    'lastUpdated' => '1252334405',
    'message' => 'Ort'
  },
  'location help' => {
    'lastUpdated' => '1252334434',
    'message' => 'Ort an dem der Bericht handelt'
  },
  'location tmplvar' => {
    'lastUpdated' => '1252334443',
    'message' => 'Ort des Berichts'
  },
  'locationForm' => {
    'lastUpdated' => '1252334463',
    'message' => 'Formular zur Eingabe des Ortes zu diesem Bericht'
  },
  'newUploadForm' => {
    'lastUpdated' => '1252334480',
    'message' => 'Formularfeld für Bildupload'
  },
  'photo alt' => {
    'lastUpdated' => '1252334494',
    'message' => 'Alternativtext Photo'
  },
  'photo byline' => {
    'lastUpdated' => '1252334509',
    'message' => 'Photounterschrift'
  },
  'photo caption' => {
    'lastUpdated' => '1252334527',
    'message' => 'Photoüberschrift'
  },
  'photo delete' => {
    'lastUpdated' => '1252334539',
    'message' => 'Photo und Metadaten löschen'
  },
  'photo remote url' => {
    'lastUpdated' => '1303289524',
    'message' => 'Foto-Remote-URL'
  },
  'photo title' => {
    'lastUpdated' => '1252334549',
    'message' => 'Alternativtitel Photo'
  },
  'photo tmplvar' => {
    'lastUpdated' => '1252334580',
    'message' => 'Photo JSON-Blob vom Berichtsasset'
  },
  'photo url' => {
    'lastUpdated' => '1252334589',
    'message' => 'Photo-URL'
  },
  'photoWidth' => {
    'lastUpdated' => '1253865063',
    'message' => 'Breite der Photos, im Berichtarchiv für diesen Bericht definiert.'
  },
  'photo_form_loop' => {
    'lastUpdated' => '1252334659',
    'message' => 'Eine Schleife, die Unterformulare für alle Photos enthält die geladen wurden und ein Leerformular zum Upload neuer Photos'
  },
  'photo_loop' => {
    'lastUpdated' => '1252334683',
    'message' => 'Eine Schleife die Photos und Informationen zu den Photos enthält.'
  },
  'save and add another photo' => {
    'lastUpdated' => '1252334695',
    'message' => 'Speichern und neues Photo hinzufügen'
  },
  'save story' => {
    'lastUpdated' => '1252334704',
    'message' => 'Bericht speichern'
  },
  'saveAndAddButton' => {
    'lastUpdated' => '1252334769',
    'message' => 'Button zum Speichern des Formulars, dann öffnen des Bearbeitenformulars um ein weiteres Photo anzufügen.'
  },
  'saveButton' => {
    'lastUpdated' => '1252334782',
    'message' => 'Button zum Formularspeichern'
  },
  'singlePhoto' => {
    'lastUpdated' => '1252334992',
    'message' => 'Diese Templatevariable ist wahr, wenn zum Bericht nur 1 Photo hochgeladen wurde.'
  },
  'story' => {
    'lastUpdated' => '1251768283',
    'message' => 'Bericht'
  },
  'story asset template variables title' => {
    'lastUpdated' => '1266397817',
    'message' => '"Bericht"-Asset Template Variabelen'
  },
  'story help' => {
    'lastUpdated' => '1252335008',
    'message' => 'Der Bericht'
  },
  'story received' => {
    'lastUpdated' => '1252335105',
    'message' => 'Der Bericht wurde erhalten und wird nun verarbeitet, so dass er zur Site hinzugefügt werden kann. Nach der Verarbeitung steht wer zur weiteren Bearbeitung zur Verfügung. Bitte haben Sie kurz Geduld.'
  },
  'story tmplvar' => {
    'lastUpdated' => '1252335146',
    'message' => 'Der Bericht. Kann eingebundene Inhalte aus dem Rich Text Editor enthalten.'
  },
  'storyForm' => {
    'lastUpdated' => '1252335169',
    'message' => 'Formular zur Eingabe des aktuellen Berichtes'
  },
  'subtitle' => {
    'lastUpdated' => '1251768302',
    'message' => 'Untertitel'
  },
  'subtitle help' => {
    'lastUpdated' => '1252335203',
    'message' => 'Ähnlich Überschrift, enthält aber meist nähere Informationen'
  },
  'subtitle tmplvar' => {
    'lastUpdated' => '1252335212',
    'message' => 'Untertitel des Berichts'
  },
  'subtitleForm' => {
    'lastUpdated' => '1252335231',
    'message' => 'Formular zur Eingabe des Untertitels zum Bericht'
  },
  'summaryForm' => {
    'lastUpdated' => '1252335250',
    'message' => 'Formular zur Eingabe einer Zusammenfassung zum Bericht'
  },
  'titleForm' => {
    'lastUpdated' => '1251768265',
    'message' => 'Formular zur Eingabe des Berichttitels'
  },
  'updatedTime' => {
    'lastUpdated' => '1266397981',
    'message' => 'Zeitpunkt der letzten Aktualisierung des Berichts. Angabe als Zeitdauer, wie "vor 1 Stunde".'
  },
  'updatedTimeEpoch' => {
    'lastUpdated' => '1266397960',
    'message' => 'Zeitpunkt der letzten Aktualisierung des Berichts als Epoch-Angabe.'
  },
  'view template' => {
    'lastUpdated' => '1251768236',
    'message' => 'Template Bericht anzeigen'
  }
}
;

1;
